@@ -1,14 +1,10 @@
-package MooseX::Types::URI;
-BEGIN {
-  $MooseX::Types::URI::AUTHORITY = 'cpan:NUFFIN';
-}
-# git description: v0.05-16-g576eea8
-$MooseX::Types::URI::VERSION = '0.06';
+use strict;
+use warnings;
+package MooseX::Types::URI; # git description: v0.08-13-gb4d8e96
 # ABSTRACT: URI related types and coercions for Moose
 # KEYWORDS: moose types constraints coercions uri path web
 
-use strict;
-use warnings;
+our $VERSION = '0.09';
 
 use Scalar::Util qw(blessed);
 
@@ -16,10 +12,7 @@ use URI;
 use URI::QueryParam;
 use URI::WithBase;
 
-use Moose::Util::TypeConstraints;
-
 use MooseX::Types::Moose qw{Str ScalarRef HashRef};
-use MooseX::Types::Path::Class qw{File Dir};
 
 use MooseX::Types 0.40 -declare => [qw(Uri _UriWithBase _Uri FileUri DataUri)];
 use if MooseX::Types->VERSION >= 0.42, 'namespace::autoclean';
@@ -43,10 +36,13 @@ register_type_constraint($uri);
 
 coerce( Uri,
     from Str                 , via { URI->new($_) },
-    from "Path::Class::File" , via { require URI::file; URI::file::->new($_) },
-    from "Path::Class::Dir"  , via { require URI::file; URI::file::->new($_) },
-    from File                , via { require URI::file; URI::file::->new($_) },
-    from Dir                 , via { require URI::file; URI::file::->new($_) },
+    eval { +require MooseX::Types::Path::Class; 1 }
+      ? (
+        from "Path::Class::File", via { require URI::file; URI::file::->new($_) },
+        from "Path::Class::Dir" , via { require URI::file; URI::file::->new($_) },
+        from MooseX::Types::Path::Class::File() , via { require URI::file; URI::file::->new($_) },
+        from MooseX::Types::Path::Class::Dir()  , via { require URI::file; URI::file::->new($_) },
+      ) : (),
     from ScalarRef           , via { my $u = URI->new("data:"); $u->data($$_); $u },
     from HashRef             , via { require URI::FromHash; URI::FromHash::uri_object(%$_) },
 );
@@ -55,10 +51,13 @@ class_type FileUri, { class => "URI::file", parent => $uri };
 
 coerce( FileUri,
     from Str                 , via { require URI::file; URI::file::->new($_) },
-    from File                , via { require URI::file; URI::file::->new($_) },
-    from Dir                 , via { require URI::file; URI::file::->new($_) },
-    from "Path::Class::File" , via { require URI::file; URI::file::->new($_) },
-    from "Path::Class::Dir"  , via { require URI::file; URI::file::->new($_) },
+    eval { +require MooseX::Types::Path::Class; 1 }
+      ? (
+        from MooseX::Types::Path::Class::File() , via { require URI::file; URI::file::->new($_) },
+        from MooseX::Types::Path::Class::Dir()  , via { require URI::file; URI::file::->new($_) },
+        from "Path::Class::File" , via { require URI::file; URI::file::->new($_) },
+        from "Path::Class::Dir"  , via { require URI::file; URI::file::->new($_) },
+      ) : (),
 );
 
 class_type DataUri, { class => "URI::data" };
@@ -82,7 +81,7 @@ MooseX::Types::URI - URI related types and coercions for Moose
 
 =head1 VERSION
 
-version 0.06
+version 0.09
 
 =head1 SYNOPSIS
 
@@ -94,13 +93,17 @@ This package provides Moose types for fun with L<URI>s.
 
 =head1 TYPES
 
+The types are with C<ucfirst> naming convention so that they don't mask the
+L<URI> class.
+
 =head2 C<Uri>
 
 Either L<URI> or L<URI::WithBase>
 
 Coerces from C<Str> via L<URI/new>.
 
-Coerces from L<Path::Class::File> and L<Path::Class::Dir> via L<URI::file/new>.
+Coerces from L<Path::Class::File> and L<Path::Class::Dir> via L<URI::file/new> (but only if
+L<MooseX::Types::Path::Class> is installed)
 
 Coerces from C<ScalarRef> via L<URI::data/new>.
 
@@ -116,7 +119,7 @@ Coerces from C<Str> and C<ScalarRef> via L<URI::data/new>.
 
 A L<URI::file> class type.
 
-Has coercions from C<Str>, L<Path::Class::File> and L<Path::Class::Dir> via L<URI::file/new>
+Has coercions from C<Str> (and optionally L<Path::Class::File> and L<Path::Class::Dir>) via L<URI::file/new>
 
 =for stopwords DWIMier ducktyping
 
@@ -124,40 +127,40 @@ It has slightly DWIMier types than the L<URI> classes have due to
 implementation details, so the types should be more forgiving when ducktyping
 will work anyway (e.g. L<URI::WithBase> does not inherit L<URI>).
 
-=head1 TYPES
-
-The types are with C<ucfirst> naming convention so that they don't mask the
-L<URI> class.
-
 =for stopwords TODO
 
 =head1 TODO
 
 Think about L<Path::Resource> integration of some sort
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Types-URI>
+(or L<bug-MooseX-Types-URI@rt.cpan.org|mailto:bug-MooseX-Types-URI@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords Karen Etheridge Florian Ragwitz Olivier Mengué Daniel Pittman MORIYA Masaki (gardejo) Shawn M Moore
+
 =over 4
 
 =item *
 
-Daniel Pittman <daniel@rimspace.net>
-
-=item *
-
-Florian Ragwitz <rafl@debian.org>
-
-=item *
-
 Karen Etheridge <ether@cpan.org>
 
 =item *
 
-MORIYA Masaki (gardejo) <moriya@ermitejo.com>
+Florian Ragwitz <rafl@debian.org>
 
 =item *
 
@@ -165,15 +168,19 @@ Olivier Mengué <dolmen@cpan.org>
 
 =item *
 
-Shawn M Moore <sartak@gmail.com>
+Daniel Pittman <daniel@rimspace.net>
 
 =item *
 
-Yuval Kogman <nothingmuch@woobling.org>
+MORIYA Masaki (gardejo) <moriya@ermitejo.com>
+
+=item *
+
+Shawn M Moore <sartak@gmail.com>
 
 =back
 
-=head1 COPYRIGHT AND LICENSE
+=head1 COPYRIGHT AND LICENCE
 
 This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman).
 
